/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2022  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////

#include <QApplication>
#include <cmath>

#include "hexeditwidget.h"

THexEditWidget::THexEditWidget(
	const QWidget						*parent)
:QLineEdit(const_cast<QWidget*>(parent))
{
	this->setInputMask(QStringLiteral("HHHH"));
	
	connect(this,&QLineEdit::textEdited,this,&THexEditWidget::Changed);
}

THexEditWidget::~THexEditWidget(void)
{
}

double THexEditWidget::Value(
	const double						&multiplier) const
{
	double								dval(0);
	double								round_offset;
	unsigned int						uval;
	QString								text;
	bool								valid;
	static const double					ZERO_EPSILON(0.000001);
	
	text = this->text();
	uval = text.toUInt(&valid,16);
	
	if(valid)
	{
		// negative value
		if((uval & 0x8000) == 0x8000)
		{
			dval = -1.0 * static_cast<double>(0xffff - uval + 1);
			dval /= multiplier;
		}
		else
		{
			dval = static_cast<double>(uval);
			dval /= multiplier;
		}
	}
	
	if(fabs(multiplier) > ZERO_EPSILON)
	{
		round_offset = 0.5 / multiplier;
		
		if(dval > 0.0)
		{
			dval += round_offset;
		}
		else
		{
			dval -= round_offset;
		}
	}
	
	return dval;
}

void THexEditWidget::Set_Font(
	const QFont							&font)
{
	this->setFont(font);
}

void THexEditWidget::Set_Value(
	const double						&d,
	const double						&multiplier)
{
	QString								text;
	
	text = QString("%1").arg(static_cast<int>(d * multiplier),4,16,QChar('0')).toUpper();
	text = text.right(4);	// negative values are long strings 'ffff ffff ffff fffe'
	
	this->setText(text);
}


