/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2022  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////


#ifndef INPUTWIDGETHEADERFILE
#define INPUTWIDGETHEADERFILE

#include <QWidget>
#include <vector>

class QLineEdit;
class QLabel;
class QGridLayout;
class QHBoxLayout;
class QSpacerItem;
class QCheckBox;
class QToolButton;

class TInputWidget : public QWidget
{
Q_OBJECT

public:
	
struct TEntryLineData
{
	double								nominal;
	double								actual;
	double								reading;
	double								correction;
};

// CREATORS
	TInputWidget(const QWidget *parent=0, Qt::WindowFlags flags=Qt::WindowFlags());
	~TInputWidget(void);

// ACCESSORS
	std::vector<TEntryLineData> Get_Data(void) const;
	TEntryLineData Get_Data(const int index) const;
	int Nominal_Precision(void) const {return d_nominal_precision;}
	int Measured_Precision(void) const {return d_measured_precision;}

// MANIPULATORS
	void Clear(void);
	void Add_Entry(const double &nominal,const double &actual,const double &reading);
	void Set_Precision(int nominal_precision,int measured_precision);

signals:
	void Data_Changed(void);

private slots:
	void Row_Selection_Changed(void);
	void Row_Data_Changed(void);
	void Add_Row(void);
	void Remove_Rows(void);

private:

struct TEntryLine
{
	QCheckBox							*line_check;
	QLineEdit							*nominal_edit;
	QLineEdit							*actual_edit;
	QLineEdit							*reading_edit;
	QLineEdit							*correction_edit;
	QLabel								*units_label;
};
	
	QGridLayout							*d_grid_layout;
	QHBoxLayout							*d_button_hlayout;
	QToolButton							*d_add_button;
	QToolButton							*d_remove_button;
	QSpacerItem							*d_widget_vspacer;
	std::vector<TEntryLine>				d_entry_lines;
	int									d_nominal_precision;
	int									d_measured_precision;
	
	int Create_Entry_Line(void);		// returns new row number
	void Set_Entry_Line_Data(const int row,const double &nominal, const double &actual, const double &reading);
	void Clear_Entries(void);

// NOT IMPLEMENTED
	TInputWidget(const TInputWidget&);
	TInputWidget& operator=(const TInputWidget&);
};

#endif
