/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2022  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////


#include <QApplication>
#include <QFrame>
#include <QGridLayout>
#include <QHBoxLayout>
#include <QLabel>
#include <QPushButton>
#include <QSpacerItem>
#include <QSpinBox>

#include "settingsdialog.h"

TSettingsDialog::TSettingsDialog(
	const QWidget						*parent,
	const Qt::WindowFlags				flags)
:QDialog(const_cast<QWidget*>(parent),flags)
{
	QFrame								*separator_hline;
	QGridLayout							*gridLayout;
	QHBoxLayout							*button_hlayout;
	QLabel								*measured_precision_label;
	QLabel								*nominal_precision_label;
	QPushButton							*accept_button;
	QPushButton							*cancel_button;
	QSpacerItem							*button_hspacer;
	QSpacerItem							*control_hspacer;
	QSpacerItem							*dialog_vspacer;


	this->resize(377,180);

	gridLayout = new QGridLayout(this);

	nominal_precision_label = new QLabel(this);
	gridLayout->addWidget(nominal_precision_label,0,0,1,1);

	d_nominal_precision_spin = new QSpinBox(this);
	d_nominal_precision_spin->setMinimum(0);
	d_nominal_precision_spin->setMaximum(2);
	gridLayout->addWidget(d_nominal_precision_spin,0,1,1,1);

	control_hspacer = new QSpacerItem(0,0,QSizePolicy::Expanding,QSizePolicy::Minimum);
	gridLayout->addItem(control_hspacer,0,2,2,1);

	measured_precision_label = new QLabel(this);
	gridLayout->addWidget(measured_precision_label,1,0,1,1);

	d_measured_precision_spin = new QSpinBox(this);
	d_measured_precision_spin->setMinimum(0);
	d_measured_precision_spin->setMaximum(4);
	gridLayout->addWidget(d_measured_precision_spin,1,1,1,1);

	separator_hline = new QFrame(this);
	separator_hline->setFrameShape(QFrame::HLine);
	separator_hline->setFrameShadow(QFrame::Sunken);
	gridLayout->addWidget(separator_hline,2,0,1,3);

	dialog_vspacer = new QSpacerItem(0,0,QSizePolicy::Minimum,QSizePolicy::Expanding);
	gridLayout->addItem(dialog_vspacer,3,0,1,3);

	button_hlayout = new QHBoxLayout();

	button_hspacer = new QSpacerItem(0,0,QSizePolicy::Expanding,QSizePolicy::Minimum);
	button_hlayout->addItem(button_hspacer);

	cancel_button = new QPushButton(this);
	cancel_button->setAutoDefault(false);
	button_hlayout->addWidget(cancel_button);

	accept_button = new QPushButton(this);
	accept_button->setAutoDefault(true);
	button_hlayout->addWidget(accept_button);
	gridLayout->addLayout(button_hlayout,4,0,1,3);
	
	// defaults
	d_nominal_precision_spin->setValue(0);
	d_measured_precision_spin->setValue(3);

	this->setWindowTitle(QStringLiteral("Settings"));
	
	nominal_precision_label->setText(QStringLiteral("Nominal Temperature Precision:"));
	measured_precision_label->setText(QStringLiteral("Measured Temperature Precision:"));
	cancel_button->setText(QStringLiteral("Cancel"));
	accept_button->setText(QStringLiteral("Accept"));
	
	connect(accept_button,&QPushButton::clicked,this,&TSettingsDialog::accept);
	connect(cancel_button,&QPushButton::clicked,this,&TSettingsDialog::reject);
}

TSettingsDialog::~TSettingsDialog(void)
{
}

int TSettingsDialog::Nominal_Precision(void) const
{
	return d_nominal_precision_spin->value();
}

int TSettingsDialog::Measured_Precision(void) const
{
	return d_measured_precision_spin->value();
}

void TSettingsDialog::Reset(
	int									Nominal_Precision,
	int									Measured_Precision)
{
	d_nominal_precision_spin->setValue(Nominal_Precision);
	d_measured_precision_spin->setValue(Measured_Precision);
}

